@@ -157,12 +157,21 @@ _nlu_requests = {
         'backstory:enter_virtual_world',
 
     # # todo - What can you talk about
-    # '{'
-    # '[what, can {you, we} {talk about, discuss}], '
-    # '[what, do you, {know about, talk about, discuss}]'
-    # '}':{
-    #
-    # },
+    '{'
+    '[what, can {you, we} {talk about, discuss}], '
+    '[what, do you, {know, talk about, discuss}]'
+    '}':{
+        'state': 'what_can_we_talk_about_q',
+        'score': 4.0,
+
+        '`I really like talking about things where we can get to know each other better. '
+        'Usually I talk to people about their travel plans, families, or how their work '
+        'or school is going.`':{
+            'state': 'what_can_we_talk_about',
+
+            '#UNX': {'#GRET': 'SYSTEM:root', 'state': 'what_can_we_talk_about_unx'}
+        }
+    },
 
     # Can we talk about something else
     '{'
@@ -206,6 +215,85 @@ _nlu_requests = {
         'score': 9.1
     },
 
+    # transition to baby
+    '[{'
+    '[do you, know], [have you, heard], [tell me about],'
+    '[!#NOT(not)[{let us, we, you, can you, can we, could you, could we}] {talk, converse, conversation, discuss, discussion, chat} about?]'
+    '}, #ONT(child)]'
+    '#CNC(baby) #SET($entered_kids=True) #GCLR': {
+        'state': 'baby:start',
+        'score': 10.0
+    },
+
+    # transition to school
+    '[{'
+    '[do you, know], [have you, heard], [tell me about],'
+    '[!#NOT(not)[{let us, we, you, can you, can we, could you, could we}] {talk, converse, conversation, discuss, discussion, chat} about?]'
+    '}, {school, homework, class, college, university}]'
+    '#CNC(school_new) #SET($entered_school=True) #GCLR': {
+        'state': 'school_new:start',
+        'score': 10.0
+    },
+
+    # transition to work
+    '[{'
+    '[do you, know], [have you, heard], [tell me about],'
+    '[!#NOT(not)[{let us, we, you, can you, can we, could you, could we}] {talk, converse, conversation, discuss, discussion, chat} about?]'
+    '}, {work, job, working}]'
+    '#CNC(worklife) #SET($entered_work=True) #GCLR': {
+        'state': 'worklife:start',
+        'score': 10.0
+    },
+
+    # transition to marriage
+    '[{'
+    '[do you, know], [have you, heard], [tell me about],'
+    '[!#NOT(not)[{let us, we, you, can you, can we, could you, could we}] {talk, converse, conversation, discuss, discussion, chat} about?]'
+    '}, {marriage, wedding, wife, husband, spouse}]'
+    '#CNC(relationships) #SET($entered_marriage=True) #GCLR': {
+        'state': 'relationships:marriage',
+        'score': 10.0
+    },
+
+    # transition to dating
+    '[{'
+    '[do you, know], [have you, heard], [tell me about],'
+    '[!#NOT(not)[{let us, we, you, can you, can we, could you, could we}] {talk, converse, conversation, discuss, discussion, chat} about?]'
+    '}, {dating, boyfriend, girlfriend, relationship, relationships}]'
+    '#CNC(relationships) #SET($entered_dating=True) #GCLR': {
+        'state': 'relationships:dating',
+        'score': 10.0
+    },
+
+    # transition to sibling
+    '[{'
+    '[do you, know], [have you, heard], [tell me about],'
+    '[!#NOT(not)[{let us, we, you, can you, can we, could you, could we}] {talk, converse, conversation, discuss, discussion, chat} about?]'
+    '}, {#LEM(sibling), #LEM(sister), #LEM(brother), #LEM(family)}]'
+    '#CNC(sibling) #SET($entered_sibling=True) #GCLR': {
+        'state': 'sibling:start',
+        'score': 10.0
+    },
+
+    # transition to hobbies
+    '[{'
+    '[do you, know], [have you, heard], [tell me about],'
+    '[!#NOT(not)[{let us, we, you, can you, can we, could you, could we}] {talk, converse, conversation, discuss, discussion, chat} about?]'
+    '}, {hobby, hobbies, things to do, activities}]'
+    '#CNC(hobby) #SET($entered_hobby=True) #GCLR': {
+        'state': 'hobby:start',
+        'score': 10.0
+    },
+
+    # transition to house
+    '[{'
+    '[do you, know], [have you, heard], [tell me about],'
+    '[!#NOT(not)[{let us, we, you, can you, can we, could you, could we}] {talk, converse, conversation, discuss, discussion, chat} about?]'
+    '}, {apartment, where you live, where you are living, house, home}]'
+    '#CNC(hobby) #SET($entered_house=True) #GCLR': {
+        'state': 'house:start',
+        'score': 10.0
+    },
 
     # transition to vr
     '[{'
@@ -251,11 +339,28 @@ _nlu_requests = {
     '[{china,chinese,wuhan,global,widespread,pandemic,epidemic},{virus,disease,illness}],'
     '[{virus,disease,illness},{china,chinese,wuhan,global,widespread,pandemic,epidemic}]'
     '}]'
-    '#CNC(coronavirus_op) #GCLR':{
-        'state': 'SYSTEM:coronavirus_op_intro',
+    '#CNC(cv_final) #IF($cv_final!=True) #GCLR':{
+        'state': 'cv_final:start',
         'score': 9.1
     },
 
+    '[{'
+    '[do you, know], [have you, heard], [tell me about],'
+    '[!#NOT(not)[{let us, we, you, can you, can we, could you, could we}] {talk, converse, conversation, discuss, discussion, chat} about?]'
+    '}, '
+    '{coronavirus,corona virus,covid,'
+    '[{china,chinese,wuhan,global,widespread,pandemic,epidemic},{virus,disease,illness}],'
+    '[{virus,disease,illness},{china,chinese,wuhan,global,widespread,pandemic,epidemic}]'
+    '}]'
+    '#CNC(cv_final) #IF($cv_final=True) #GCLR': {
+        'state': 'return_to_corona',
+        'score': 9.1,
+
+        '`Sorry, I don\'t know too much more about the coronavirus. I just really hope things get better for you soon '
+        'and you and your loved ones stay healthy. Anyways, `':
+            'SYSTEM:root'
+    },
+
 
     # Do you know
     '#NOT(travel,traveling,city,cities,vacation,vacations,'
