@@ -94,6 +94,21 @@ class ONTN(Macro):
             return ont_result
 
 
+class ONTUL(Macro):
+    """
+   get the set of expressions matching the entire descendent subtree
+   underneath a given set of ontology nodes (usually 1)
+   """
+
+    def __init__(self, kb):
+        self.kb = kb
+
+    def run(self, ngrams: Ngrams, vars: Dict[str, Any], args: List[Any]):
+        node_set = set(_process_args_set(args, vars))
+        ont_result = self.kb.expressions(self.kb.subtypes(node_set))
+        return ont_result.intersection(ngrams)
+
+
 class ONT_NEG(Macro):
     def __init__(self, kb):
         self.kb = kb
@@ -282,11 +297,11 @@ def _term_op_term(arg, vars):
         if '<=' in arg:
             operator = '<='
             t1, t2 = _get_terms(arg, operator, vars)
-            return t1 <= t2
+            return float(t1) <= float(t2)
         elif '>=' in arg:
             operator = '>='
             t1, t2 = _get_terms(arg, operator, vars)
-            return t1 >= t2
+            return float(t1) >= float(t2)
         elif '!=' in arg:
             operator = '!='
             t1, t2 = _get_terms(arg, operator, vars)
@@ -294,11 +309,11 @@ def _term_op_term(arg, vars):
         elif '<' in arg:
             operator = '<'
             t1, t2 = _get_terms(arg, operator, vars)
-            return t1 < t2
+            return float(t1) < float(t2)
         elif '>' in arg:
             operator = '>'
             t1, t2 = _get_terms(arg, operator, vars)
-            return t1 > t2
+            return float(t1) > float(t2)
         elif '=' in arg:
             operator = '='
             t1, t2 = _get_terms(arg, operator, vars)
@@ -486,8 +501,6 @@ class NamedEntity(Macro):
               DATE, TIME, PERCENT, MONEY, QUANTITY, ORDINAL, CARDINAL
         https://spacy.io/api/annotation
     """
-    def __init__(self):
-        pass
     def run(self, ngrams: Ngrams, vars: Dict[str, Any], args: List[Any]):
         doc = nlp(ngrams.text())
         entities = set()
@@ -992,7 +1005,7 @@ class ExtractList(Macro):
 
     def run(self, ngrams: Ngrams, vars: Dict[str, Any], args: List[Any]):
         var = args[0]
-        if var not in vars:
+        if var not in vars or vars[var] == 'None':
             vars[var] = set()
         # find matches
         matches = self.onte(ngrams, None, args[1:])
